/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.dbunit;

import org.dbunit.IDatabaseTester;
import org.dbunit.operation.DatabaseOperation;
import org.dbunit.dataset.IDataSet;

/**
 * Utility allowing for creating a dbunit database tester in one line (ideally, the field declaration).
 *
 * @author Jared Bunting
 */
public class IDatabaseTesterBuilder {

  private IDatabaseTester iDatabaseTester;

  private IDatabaseTesterBuilder(IDatabaseTester iDatabaseTester) {
    this.iDatabaseTester = iDatabaseTester;
  }

  public static IDatabaseTesterBuilder from(IDatabaseTester iDatabaseTester) {
    return new IDatabaseTesterBuilder(iDatabaseTester);
  }

  public IDatabaseTesterBuilder setDataSet(IDataSet iDataSet) {
    iDatabaseTester.setDataSet(iDataSet);
    return this;
  }

  public IDatabaseTesterBuilder setSchema(String schema) {
    iDatabaseTester.setSchema(schema);
    return this;
  }

  public IDatabaseTesterBuilder setSetUpOperation(DatabaseOperation setupOperation) {
    iDatabaseTester.setSetUpOperation(setupOperation);
    return this;
  }

  public IDatabaseTesterBuilder setTearDownOperation(DatabaseOperation tearDownOperation) {
    iDatabaseTester.setTearDownOperation(tearDownOperation);
    return this;
  }

  public IDatabaseTester create() {
    return null;
  }
}
